OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Детали",
    "Rename" : "Преименувај",
    "Move" : "Премести",
    "Delete" : "Избриши",
    "Search" : "Барај",
    "New" : "Ново",
    "New folder" : "Нова папка",
    "Grid view" : "Мрежа",
    "List view" : "Листа",
    "RSS Feed of current view" : "RSS канал од моменталниот поглед",
    "Select all" : "Избери се",
    "Submit" : "Испрати",
    "Cancel" : "Откажи",
    "Recent" : "Неодамнешни",
    "Import" : "Увези",
    "Export" : "Извези",
    "Recently added" : "Скоро додадени",
    "Alphabetically" : "Азбучно",
    "Last modified" : "Скоро изменети",
    "Clear data" : "Исчисти податоци",
    "Title" : "Наслов",
    "Link" : "Линк",
    "Tags" : "Ознаки",
    "Attachments" : "Прилози",
    "Notes" : "Белешки",
    "Owner" : "Сопственик",
    "Sharing" : "Споделување",
    "Select a user or group" : "Избери корисник или група",
    "Share link" : "Сподели линк",
    "Copy link" : "Копирај линк",
    "Copy RSS feed" : "Копирај RSS канал",
    "Allow editing" : "Овозможи уредување",
    "Remove share" : "Отстрани споделување",
    "Link copied" : "Линкот е копиран",
    "RSS feed copied" : "RSS канал копиран",
    "Select" : "Select",
    "Privacy" : "Приватност",
    "Failed to save settings" : "Неуспешно зачувување на параметрите",
    "Folder" : "Папка",
    "Save" : "Зачувај"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
